# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import absolute_import

import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr, conint, conlist

from typing import Any, Dict, Optional

from synctera_client_ng.models.document import Document
from synctera_client_ng.models.document_list import DocumentList
from synctera_client_ng.models.document_type import DocumentType
from synctera_client_ng.models.encryption import Encryption
from synctera_client_ng.models.patch_document import PatchDocument
from synctera_client_ng.models.related_resource_type import RelatedResourceType

from synctera_client_ng.api_client import ApiClient
from synctera_client_ng.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DocumentsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_document(self, file : Annotated[StrictStr, Field(..., description="The file contents")], description : Annotated[Optional[StrictStr], Field(description="A description of the attached document")] = None, encryption : Optional[Encryption] = None, is_restricted : Annotated[Optional[StrictBool], Field(description="whether this document should be restricted (special permissions will be used to access restricted documents)")] = None, metadata : Annotated[Optional[Dict[str, Any]], Field(description="Optional field to store additional information about the resource. Intended to be used by the integrator to store non-sensitive data. ")] = None, name : Annotated[Optional[StrictStr], Field(description="A user-friendly name for the document")] = None, related_resource_id : Annotated[Optional[StrictStr], Field(description="The ID of the resource related to the document")] = None, related_resource_type : Optional[RelatedResourceType] = None, tenant : Annotated[Optional[StrictStr], Field(description="The id of the tenant containing the resource. ")] = None, type : Optional[DocumentType] = None, **kwargs) -> Document:  # noqa: E501
        """Create a document  # noqa: E501

        Docs   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_document(file, description, encryption, is_restricted, metadata, name, related_resource_id, related_resource_type, tenant, type, async_req=True)
        >>> result = thread.get()

        :param file: The file contents (required)
        :type file: str
        :param description: A description of the attached document
        :type description: str
        :param encryption:
        :type encryption: Encryption
        :param is_restricted: whether this document should be restricted (special permissions will be used to access restricted documents)
        :type is_restricted: bool
        :param metadata: Optional field to store additional information about the resource. Intended to be used by the integrator to store non-sensitive data. 
        :type metadata: object
        :param name: A user-friendly name for the document
        :type name: str
        :param related_resource_id: The ID of the resource related to the document
        :type related_resource_id: str
        :param related_resource_type:
        :type related_resource_type: RelatedResourceType
        :param tenant: The id of the tenant containing the resource. 
        :type tenant: str
        :param type:
        :type type: DocumentType
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Document
        """
        kwargs['_return_http_data_only'] = True
        return self.create_document_with_http_info(file, description, encryption, is_restricted, metadata, name, related_resource_id, related_resource_type, tenant, type, **kwargs)  # noqa: E501

    @validate_arguments
    def create_document_with_http_info(self, file : Annotated[StrictStr, Field(..., description="The file contents")], description : Annotated[Optional[StrictStr], Field(description="A description of the attached document")] = None, encryption : Optional[Encryption] = None, is_restricted : Annotated[Optional[StrictBool], Field(description="whether this document should be restricted (special permissions will be used to access restricted documents)")] = None, metadata : Annotated[Optional[Dict[str, Any]], Field(description="Optional field to store additional information about the resource. Intended to be used by the integrator to store non-sensitive data. ")] = None, name : Annotated[Optional[StrictStr], Field(description="A user-friendly name for the document")] = None, related_resource_id : Annotated[Optional[StrictStr], Field(description="The ID of the resource related to the document")] = None, related_resource_type : Optional[RelatedResourceType] = None, tenant : Annotated[Optional[StrictStr], Field(description="The id of the tenant containing the resource. ")] = None, type : Optional[DocumentType] = None, **kwargs):  # noqa: E501
        """Create a document  # noqa: E501

        Docs   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_document_with_http_info(file, description, encryption, is_restricted, metadata, name, related_resource_id, related_resource_type, tenant, type, async_req=True)
        >>> result = thread.get()

        :param file: The file contents (required)
        :type file: str
        :param description: A description of the attached document
        :type description: str
        :param encryption:
        :type encryption: Encryption
        :param is_restricted: whether this document should be restricted (special permissions will be used to access restricted documents)
        :type is_restricted: bool
        :param metadata: Optional field to store additional information about the resource. Intended to be used by the integrator to store non-sensitive data. 
        :type metadata: object
        :param name: A user-friendly name for the document
        :type name: str
        :param related_resource_id: The ID of the resource related to the document
        :type related_resource_id: str
        :param related_resource_type:
        :type related_resource_type: RelatedResourceType
        :param tenant: The id of the tenant containing the resource. 
        :type tenant: str
        :param type:
        :type type: DocumentType
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Document, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'file',
            'description',
            'encryption',
            'is_restricted',
            'metadata',
            'name',
            'related_resource_id',
            'related_resource_type',
            'tenant',
            'type'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_document" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        if _params['description']:
            _form_params.append(('description', _params['description']))

        if _params['encryption']:
            _form_params.append(('encryption', _params['encryption']))

        if _params['file']:
            _files['file'] = _params['file']

        if _params['is_restricted']:
            _form_params.append(('is_restricted', _params['is_restricted']))

        if _params['metadata']:
            _form_params.append(('metadata', _params['metadata']))

        if _params['name']:
            _form_params.append(('name', _params['name']))

        if _params['related_resource_id']:
            _form_params.append(('related_resource_id', _params['related_resource_id']))

        if _params['related_resource_type']:
            _form_params.append(('related_resource_type', _params['related_resource_type']))

        if _params['tenant']:
            _form_params.append(('tenant', _params['tenant']))

        if _params['type']:
            _form_params.append(('type', _params['type']))

        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['multipart/form-data']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '201': "Document",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '409': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/documents', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def create_document_version(self, document_id : Annotated[StrictStr, Field(..., description="The unique identifier of the document.")], file : Annotated[StrictStr, Field(..., description="The file contents")], description : Annotated[Optional[StrictStr], Field(description="A description of the attached document")] = None, encryption : Optional[Encryption] = None, name : Annotated[Optional[StrictStr], Field(description="A user-friendly name for the document")] = None, type : Optional[DocumentType] = None, **kwargs) -> Document:  # noqa: E501
        """Create a new document version  # noqa: E501

        Docs   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_document_version(document_id, file, description, encryption, name, type, async_req=True)
        >>> result = thread.get()

        :param document_id: The unique identifier of the document. (required)
        :type document_id: str
        :param file: The file contents (required)
        :type file: str
        :param description: A description of the attached document
        :type description: str
        :param encryption:
        :type encryption: Encryption
        :param name: A user-friendly name for the document
        :type name: str
        :param type:
        :type type: DocumentType
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Document
        """
        kwargs['_return_http_data_only'] = True
        return self.create_document_version_with_http_info(document_id, file, description, encryption, name, type, **kwargs)  # noqa: E501

    @validate_arguments
    def create_document_version_with_http_info(self, document_id : Annotated[StrictStr, Field(..., description="The unique identifier of the document.")], file : Annotated[StrictStr, Field(..., description="The file contents")], description : Annotated[Optional[StrictStr], Field(description="A description of the attached document")] = None, encryption : Optional[Encryption] = None, name : Annotated[Optional[StrictStr], Field(description="A user-friendly name for the document")] = None, type : Optional[DocumentType] = None, **kwargs):  # noqa: E501
        """Create a new document version  # noqa: E501

        Docs   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_document_version_with_http_info(document_id, file, description, encryption, name, type, async_req=True)
        >>> result = thread.get()

        :param document_id: The unique identifier of the document. (required)
        :type document_id: str
        :param file: The file contents (required)
        :type file: str
        :param description: A description of the attached document
        :type description: str
        :param encryption:
        :type encryption: Encryption
        :param name: A user-friendly name for the document
        :type name: str
        :param type:
        :type type: DocumentType
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Document, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'document_id',
            'file',
            'description',
            'encryption',
            'name',
            'type'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_document_version" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['document_id']:
            _path_params['document_id'] = _params['document_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        if _params['description']:
            _form_params.append(('description', _params['description']))

        if _params['encryption']:
            _form_params.append(('encryption', _params['encryption']))

        if _params['file']:
            _files['file'] = _params['file']

        if _params['name']:
            _form_params.append(('name', _params['name']))

        if _params['type']:
            _form_params.append(('type', _params['type']))

        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['multipart/form-data']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '201': "Document",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '409': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/documents/{document_id}/versions', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_document(self, document_id : Annotated[StrictStr, Field(..., description="The unique identifier of the document.")], **kwargs) -> Document:  # noqa: E501
        """Get a document  # noqa: E501

        Returns the document attributes. Use /documents/{document_id}/contents to get the contents.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_document(document_id, async_req=True)
        >>> result = thread.get()

        :param document_id: The unique identifier of the document. (required)
        :type document_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Document
        """
        kwargs['_return_http_data_only'] = True
        return self.get_document_with_http_info(document_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_document_with_http_info(self, document_id : Annotated[StrictStr, Field(..., description="The unique identifier of the document.")], **kwargs):  # noqa: E501
        """Get a document  # noqa: E501

        Returns the document attributes. Use /documents/{document_id}/contents to get the contents.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_document_with_http_info(document_id, async_req=True)
        >>> result = thread.get()

        :param document_id: The unique identifier of the document. (required)
        :type document_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Document, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'document_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_document" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['document_id']:
            _path_params['document_id'] = _params['document_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "Document",
            '401': "Error",
            '403': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/documents/{document_id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_document_contents(self, document_id : Annotated[StrictStr, Field(..., description="The unique identifier of the document.")], **kwargs) -> str:  # noqa: E501
        """Get contents of latest document version  # noqa: E501

        Returns the bytes of the requested document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_document_contents(document_id, async_req=True)
        >>> result = thread.get()

        :param document_id: The unique identifier of the document. (required)
        :type document_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: str
        """
        kwargs['_return_http_data_only'] = True
        return self.get_document_contents_with_http_info(document_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_document_contents_with_http_info(self, document_id : Annotated[StrictStr, Field(..., description="The unique identifier of the document.")], **kwargs):  # noqa: E501
        """Get contents of latest document version  # noqa: E501

        Returns the bytes of the requested document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_document_contents_with_http_info(document_id, async_req=True)
        >>> result = thread.get()

        :param document_id: The unique identifier of the document. (required)
        :type document_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(str, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'document_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_document_contents" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['document_id']:
            _path_params['document_id'] = _params['document_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*', 'application/problem+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "str",
            '401': "Error",
            '403': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/documents/{document_id}/contents', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_document_version(self, document_id : Annotated[StrictStr, Field(..., description="The unique identifier of the document.")], document_version : Annotated[StrictInt, Field(..., description="The document version.")], **kwargs) -> Document:  # noqa: E501
        """Get a document by version  # noqa: E501

        Returns the document (attributes). Use /documents/{document_id}/versions/{version}/contents to get the contents.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_document_version(document_id, document_version, async_req=True)
        >>> result = thread.get()

        :param document_id: The unique identifier of the document. (required)
        :type document_id: str
        :param document_version: The document version. (required)
        :type document_version: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Document
        """
        kwargs['_return_http_data_only'] = True
        return self.get_document_version_with_http_info(document_id, document_version, **kwargs)  # noqa: E501

    @validate_arguments
    def get_document_version_with_http_info(self, document_id : Annotated[StrictStr, Field(..., description="The unique identifier of the document.")], document_version : Annotated[StrictInt, Field(..., description="The document version.")], **kwargs):  # noqa: E501
        """Get a document by version  # noqa: E501

        Returns the document (attributes). Use /documents/{document_id}/versions/{version}/contents to get the contents.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_document_version_with_http_info(document_id, document_version, async_req=True)
        >>> result = thread.get()

        :param document_id: The unique identifier of the document. (required)
        :type document_id: str
        :param document_version: The document version. (required)
        :type document_version: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Document, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'document_id',
            'document_version'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_document_version" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['document_id']:
            _path_params['document_id'] = _params['document_id']

        if _params['document_version']:
            _path_params['document_version'] = _params['document_version']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "Document",
            '401': "Error",
            '403': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/documents/{document_id}/versions/{document_version}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_document_version_contents(self, document_id : Annotated[StrictStr, Field(..., description="The unique identifier of the document.")], document_version : Annotated[StrictInt, Field(..., description="The document version.")], **kwargs) -> str:  # noqa: E501
        """Get document contents by version  # noqa: E501

        Returns the bytes of the requested document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_document_version_contents(document_id, document_version, async_req=True)
        >>> result = thread.get()

        :param document_id: The unique identifier of the document. (required)
        :type document_id: str
        :param document_version: The document version. (required)
        :type document_version: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: str
        """
        kwargs['_return_http_data_only'] = True
        return self.get_document_version_contents_with_http_info(document_id, document_version, **kwargs)  # noqa: E501

    @validate_arguments
    def get_document_version_contents_with_http_info(self, document_id : Annotated[StrictStr, Field(..., description="The unique identifier of the document.")], document_version : Annotated[StrictInt, Field(..., description="The document version.")], **kwargs):  # noqa: E501
        """Get document contents by version  # noqa: E501

        Returns the bytes of the requested document.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_document_version_contents_with_http_info(document_id, document_version, async_req=True)
        >>> result = thread.get()

        :param document_id: The unique identifier of the document. (required)
        :type document_id: str
        :param document_version: The document version. (required)
        :type document_version: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(str, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'document_id',
            'document_version'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_document_version_contents" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['document_id']:
            _path_params['document_id'] = _params['document_id']

        if _params['document_version']:
            _path_params['document_version'] = _params['document_version']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*', 'application/problem+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "str",
            '401': "Error",
            '403': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/documents/{document_id}/versions/{document_version}/contents', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_documents(self, id : Annotated[Optional[conlist(StrictStr)], Field(description="Unique resource identifier")] = None, tenant : Optional[StrictStr] = None, limit : Optional[conint(strict=True, ge=1)] = None, page_token : Optional[StrictStr] = None, related_resource_type : Annotated[Optional[RelatedResourceType], Field(description="Return documents that are related to resources of the specified type")] = None, related_resource_id : Annotated[Optional[StrictStr], Field(description="Return documents that are related to resources with the specified ID")] = None, encryption : Annotated[Optional[StrictStr], Field(description="Whether the file should be encrypted and access restricted, e.g. if the file contains PII")] = None, type : Annotated[Optional[DocumentType], Field(description="The type of documents")] = None, **kwargs) -> DocumentList:  # noqa: E501
        """List documents  # noqa: E501

        Returns a paginated list of documents (metadata only, not contents).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_documents(id, tenant, limit, page_token, related_resource_type, related_resource_id, encryption, type, async_req=True)
        >>> result = thread.get()

        :param id: Unique resource identifier
        :type id: List[str]
        :param tenant:
        :type tenant: str
        :param limit:
        :type limit: int
        :param page_token:
        :type page_token: str
        :param related_resource_type: Return documents that are related to resources of the specified type
        :type related_resource_type: RelatedResourceType
        :param related_resource_id: Return documents that are related to resources with the specified ID
        :type related_resource_id: str
        :param encryption: Whether the file should be encrypted and access restricted, e.g. if the file contains PII
        :type encryption: str
        :param type: The type of documents
        :type type: DocumentType
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DocumentList
        """
        kwargs['_return_http_data_only'] = True
        return self.list_documents_with_http_info(id, tenant, limit, page_token, related_resource_type, related_resource_id, encryption, type, **kwargs)  # noqa: E501

    @validate_arguments
    def list_documents_with_http_info(self, id : Annotated[Optional[conlist(StrictStr)], Field(description="Unique resource identifier")] = None, tenant : Optional[StrictStr] = None, limit : Optional[conint(strict=True, ge=1)] = None, page_token : Optional[StrictStr] = None, related_resource_type : Annotated[Optional[RelatedResourceType], Field(description="Return documents that are related to resources of the specified type")] = None, related_resource_id : Annotated[Optional[StrictStr], Field(description="Return documents that are related to resources with the specified ID")] = None, encryption : Annotated[Optional[StrictStr], Field(description="Whether the file should be encrypted and access restricted, e.g. if the file contains PII")] = None, type : Annotated[Optional[DocumentType], Field(description="The type of documents")] = None, **kwargs):  # noqa: E501
        """List documents  # noqa: E501

        Returns a paginated list of documents (metadata only, not contents).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_documents_with_http_info(id, tenant, limit, page_token, related_resource_type, related_resource_id, encryption, type, async_req=True)
        >>> result = thread.get()

        :param id: Unique resource identifier
        :type id: List[str]
        :param tenant:
        :type tenant: str
        :param limit:
        :type limit: int
        :param page_token:
        :type page_token: str
        :param related_resource_type: Return documents that are related to resources of the specified type
        :type related_resource_type: RelatedResourceType
        :param related_resource_id: Return documents that are related to resources with the specified ID
        :type related_resource_id: str
        :param encryption: Whether the file should be encrypted and access restricted, e.g. if the file contains PII
        :type encryption: str
        :param type: The type of documents
        :type type: DocumentType
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(DocumentList, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id',
            'tenant',
            'limit',
            'page_token',
            'related_resource_type',
            'related_resource_id',
            'encryption',
            'type'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_documents" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('id') is not None:  # noqa: E501
            _query_params.append(('id', _params['id']))
            _collection_formats['id'] = 'csv'

        if _params.get('tenant') is not None:  # noqa: E501
            _query_params.append(('tenant', _params['tenant']))

        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('page_token') is not None:  # noqa: E501
            _query_params.append(('page_token', _params['page_token']))

        if _params.get('related_resource_type') is not None:  # noqa: E501
            _query_params.append(('related_resource_type', _params['related_resource_type']))

        if _params.get('related_resource_id') is not None:  # noqa: E501
            _query_params.append(('related_resource_id', _params['related_resource_id']))

        if _params.get('encryption') is not None:  # noqa: E501
            _query_params.append(('encryption', _params['encryption']))

        if _params.get('type') is not None:  # noqa: E501
            _query_params.append(('type', _params['type']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "DocumentList",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/documents', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def update_document(self, document_id : Annotated[StrictStr, Field(..., description="The unique identifier of the document.")], patch_document : PatchDocument, **kwargs) -> Document:  # noqa: E501
        """Update a document  # noqa: E501

        Update attributes of the latest document version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_document(document_id, patch_document, async_req=True)
        >>> result = thread.get()

        :param document_id: The unique identifier of the document. (required)
        :type document_id: str
        :param patch_document: (required)
        :type patch_document: PatchDocument
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Document
        """
        kwargs['_return_http_data_only'] = True
        return self.update_document_with_http_info(document_id, patch_document, **kwargs)  # noqa: E501

    @validate_arguments
    def update_document_with_http_info(self, document_id : Annotated[StrictStr, Field(..., description="The unique identifier of the document.")], patch_document : PatchDocument, **kwargs):  # noqa: E501
        """Update a document  # noqa: E501

        Update attributes of the latest document version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_document_with_http_info(document_id, patch_document, async_req=True)
        >>> result = thread.get()

        :param document_id: The unique identifier of the document. (required)
        :type document_id: str
        :param patch_document: (required)
        :type patch_document: PatchDocument
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Document, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'document_id',
            'patch_document'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_document" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['document_id']:
            _path_params['document_id'] = _params['document_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['patch_document']:
            _body_params = _params['patch_document']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "Document",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/documents/{document_id}', 'PATCH',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class Status2(str, Enum):
    """
    Status of the person. One of the following: * `ACTIVE` – is an integrator defined status.  Integrators should set a person to active if they believe the person to be qualified for conducting business.  Synctera will combine this status with other statuses such a verification to determine if the person is eligible for specific actions such as initiating transactions or issuing a card. * `DECEASED` – person is deceased. * `DENIED` – customer was turned down. * `DORMANT` – person is no longer active. * `ESCHEAT` – person's assets are abandoned and are property of the state. * `FROZEN` – person's actions are blocked for security, legal, or other reasons. * `INACTIVE` – an inactive status indicating that the person is no longer active. * `PROSPECT` – a potential customer, used for information-gathering and disclosures. * `SANCTION` – person is on a sanctions list and should be carefully monitored. 
    """

    """
    allowed enum values
    """
    ACTIVE = 'ACTIVE'
    DECEASED = 'DECEASED'
    DENIED = 'DENIED'
    DORMANT = 'DORMANT'
    ESCHEAT = 'ESCHEAT'
    FROZEN = 'FROZEN'
    INACTIVE = 'INACTIVE'
    PROSPECT = 'PROSPECT'
    SANCTION = 'SANCTION'




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class CardImageMode(str, Enum):
    """
    The image mode of a card product. If the card product supports custom card images, this value determines how the images will be handled during card issuance. REQUIRED means that cards issued with this card product must have the ID of an image that has been uploaded. Note that the image does not necessarily have to have been approved prior to the issuance request. This mode is currently disabled. REQUIRED_APPROVED_FIRST means that cards issued with this card product must have the ID of an image that has been uploaded and approved. 
    """

    """
    allowed enum values
    """
    REQUIRED = 'REQUIRED'
    REQUIRED_APPROVED_FIRST = 'REQUIRED_APPROVED_FIRST'




# coding: utf-8

# flake8: noqa

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import absolute_import

__version__ = "0.41.0"

# import apis into sdk package
from synctera_client_ng.api.ach_api import ACHApi
from synctera_client_ng.api.ach_transaction_simulations_api import ACHTransactionSimulationsApi
from synctera_client_ng.api.accounts_api import AccountsApi
from synctera_client_ng.api.businesses_api import BusinessesApi
from synctera_client_ng.api.card_transaction_simulations_api import CardTransactionSimulationsApi
from synctera_client_ng.api.card_webhook_simulations_api import CardWebhookSimulationsApi
from synctera_client_ng.api.cards_api import CardsApi
from synctera_client_ng.api.cash_pickups_alpha_api import CashPickupsAlphaApi
from synctera_client_ng.api.customers_api import CustomersApi
from synctera_client_ng.api.digital_wallet_tokens_api import DigitalWalletTokensApi
from synctera_client_ng.api.disclosures_api import DisclosuresApi
from synctera_client_ng.api.disclosures_deprecated_api import DisclosuresDeprecatedApi
from synctera_client_ng.api.documents_api import DocumentsApi
from synctera_client_ng.api.external_accounts_api import ExternalAccountsApi
from synctera_client_ng.api.external_cards_api import ExternalCardsApi
from synctera_client_ng.api.internal_accounts_api import InternalAccountsApi
from synctera_client_ng.api.internal_transfer_api import InternalTransferApi
from synctera_client_ng.api.kyckyb_verifications_api import KYCKYBVerificationsApi
from synctera_client_ng.api.kyc_verification_deprecated_api import KYCVerificationDeprecatedApi
from synctera_client_ng.api.monitoring_api import MonitoringApi
from synctera_client_ng.api.notes_api import NotesApi
from synctera_client_ng.api.payment_schedules_api import PaymentSchedulesApi
from synctera_client_ng.api.persons_api import PersonsApi
from synctera_client_ng.api.relationships_api import RelationshipsApi
from synctera_client_ng.api.remote_check_deposit_beta_api import RemoteCheckDepositBetaApi
from synctera_client_ng.api.sandbox_wipe_alpha_api import SandboxWipeAlphaApi
from synctera_client_ng.api.spend_controls_beta_api import SpendControlsBetaApi
from synctera_client_ng.api.statements_api import StatementsApi
from synctera_client_ng.api.transactions_api import TransactionsApi
from synctera_client_ng.api.watchlist_deprecated_api import WatchlistDeprecatedApi
from synctera_client_ng.api.webhooks_api import WebhooksApi
from synctera_client_ng.api.wires_alpha_api import WiresAlphaApi

# import ApiClient
from synctera_client_ng.api_client import ApiClient
from synctera_client_ng.configuration import Configuration
from synctera_client_ng.exceptions import OpenApiException
from synctera_client_ng.exceptions import ApiTypeError
from synctera_client_ng.exceptions import ApiValueError
from synctera_client_ng.exceptions import ApiKeyError
from synctera_client_ng.exceptions import ApiAttributeError
from synctera_client_ng.exceptions import ApiException
# import models into sdk package
from synctera_client_ng.models.account import Account
from synctera_client_ng.models.account_access_status import AccountAccessStatus
from synctera_client_ng.models.account_base import AccountBase
from synctera_client_ng.models.account_charge_secured import AccountChargeSecured
from synctera_client_ng.models.account_charge_secured_all_of import AccountChargeSecuredAllOf
from synctera_client_ng.models.account_creation import AccountCreation
from synctera_client_ng.models.account_creation_all_of import AccountCreationAllOf
from synctera_client_ng.models.account_depository import AccountDepository
from synctera_client_ng.models.account_depository_all_of import AccountDepositoryAllOf
from synctera_client_ng.models.account_generic_response import AccountGenericResponse
from synctera_client_ng.models.account_identifiers import AccountIdentifiers
from synctera_client_ng.models.account_line_of_credit import AccountLineOfCredit
from synctera_client_ng.models.account_line_of_credit_all_of import AccountLineOfCreditAllOf
from synctera_client_ng.models.account_list import AccountList
from synctera_client_ng.models.account_list_all_of import AccountListAllOf
from synctera_client_ng.models.account_product import AccountProduct
from synctera_client_ng.models.account_product_list import AccountProductList
from synctera_client_ng.models.account_product_list_all_of import AccountProductListAllOf
from synctera_client_ng.models.account_relationship_type import AccountRelationshipType
from synctera_client_ng.models.account_routing import AccountRouting
from synctera_client_ng.models.account_summary import AccountSummary
from synctera_client_ng.models.account_summary_balance_ceiling import AccountSummaryBalanceCeiling
from synctera_client_ng.models.account_summary_balance_floor import AccountSummaryBalanceFloor
from synctera_client_ng.models.account_template import AccountTemplate
from synctera_client_ng.models.account_template_response import AccountTemplateResponse
from synctera_client_ng.models.account_type import AccountType
from synctera_client_ng.models.account_verification import AccountVerification
from synctera_client_ng.models.accrual_payout_schedule import AccrualPayoutSchedule
from synctera_client_ng.models.ach_instruction import AchInstruction
from synctera_client_ng.models.ach_request_hold_data import AchRequestHoldData
from synctera_client_ng.models.ach_return_simulation_request import AchReturnSimulationRequest
from synctera_client_ng.models.ach_transaction_simulation_request import AchTransactionSimulationRequest
from synctera_client_ng.models.add_accounts_request import AddAccountsRequest
from synctera_client_ng.models.add_accounts_request_account_identifiers import AddAccountsRequestAccountIdentifiers
from synctera_client_ng.models.add_accounts_request_routing_identifiers import AddAccountsRequestRoutingIdentifiers
from synctera_client_ng.models.add_vendor_account_failure import AddVendorAccountFailure
from synctera_client_ng.models.add_vendor_accounts_error_reason import AddVendorAccountsErrorReason
from synctera_client_ng.models.add_vendor_accounts_request import AddVendorAccountsRequest
from synctera_client_ng.models.add_vendor_accounts_response import AddVendorAccountsResponse
from synctera_client_ng.models.additional_data import AdditionalData
from synctera_client_ng.models.additional_owner_data import AdditionalOwnerData
from synctera_client_ng.models.address import Address
from synctera_client_ng.models.address1 import Address1
from synctera_client_ng.models.address2 import Address2
from synctera_client_ng.models.adhoc_verification_request import AdhocVerificationRequest
from synctera_client_ng.models.adhoc_verification_response import AdhocVerificationResponse
from synctera_client_ng.models.apple_digital_wallet_provision_request import AppleDigitalWalletProvisionRequest
from synctera_client_ng.models.apple_digital_wallet_provision_response import AppleDigitalWalletProvisionResponse
from synctera_client_ng.models.application_type import ApplicationType
from synctera_client_ng.models.auth_request_model import AuthRequestModel
from synctera_client_ng.models.authorization_advice_model import AuthorizationAdviceModel
from synctera_client_ng.models.balance import Balance
from synctera_client_ng.models.balance_ceiling import BalanceCeiling
from synctera_client_ng.models.balance_floor import BalanceFloor
from synctera_client_ng.models.balance_inquiry_request_model import BalanceInquiryRequestModel
from synctera_client_ng.models.balance_type import BalanceType
from synctera_client_ng.models.ban_status import BanStatus
from synctera_client_ng.models.base import Base
from synctera_client_ng.models.base_account_verification import BaseAccountVerification
from synctera_client_ng.models.base_card import BaseCard
from synctera_client_ng.models.base_card_all_of import BaseCardAllOf
from synctera_client_ng.models.base_cash_pickup import BaseCashPickup
from synctera_client_ng.models.base_disclosure import BaseDisclosure
from synctera_client_ng.models.base_person import BasePerson
from synctera_client_ng.models.base_person1 import BasePerson1
from synctera_client_ng.models.base_statement import BaseStatement
from synctera_client_ng.models.base_statement_all_of import BaseStatementAllOf
from synctera_client_ng.models.base_template_fields import BaseTemplateFields
from synctera_client_ng.models.billing_address import BillingAddress
from synctera_client_ng.models.billing_period import BillingPeriod
from synctera_client_ng.models.business import Business
from synctera_client_ng.models.business1 import Business1
from synctera_client_ng.models.business_business_owner_relationship import BusinessBusinessOwnerRelationship
from synctera_client_ng.models.business_list import BusinessList
from synctera_client_ng.models.business_list_all_of import BusinessListAllOf
from synctera_client_ng.models.calculation_method import CalculationMethod
from synctera_client_ng.models.card_acceptor_model import CardAcceptorModel
from synctera_client_ng.models.card_activation_request import CardActivationRequest
from synctera_client_ng.models.card_brand import CardBrand
from synctera_client_ng.models.card_change import CardChange
from synctera_client_ng.models.card_change_state import CardChangeState
from synctera_client_ng.models.card_changes_list import CardChangesList
from synctera_client_ng.models.card_changes_list_all_of import CardChangesListAllOf
from synctera_client_ng.models.card_edit_request import CardEditRequest
from synctera_client_ng.models.card_format import CardFormat
from synctera_client_ng.models.card_fulfillment_status import CardFulfillmentStatus
from synctera_client_ng.models.card_image_details import CardImageDetails
from synctera_client_ng.models.card_image_details_list import CardImageDetailsList
from synctera_client_ng.models.card_image_details_list_all_of import CardImageDetailsListAllOf
from synctera_client_ng.models.card_image_mode import CardImageMode
from synctera_client_ng.models.card_image_rejection_reason import CardImageRejectionReason
from synctera_client_ng.models.card_image_status import CardImageStatus
from synctera_client_ng.models.card_issuance_request import CardIssuanceRequest
from synctera_client_ng.models.card_list_response import CardListResponse
from synctera_client_ng.models.card_list_response_all_of import CardListResponseAllOf
from synctera_client_ng.models.card_options import CardOptions
from synctera_client_ng.models.card_pin_status import CardPinStatus
from synctera_client_ng.models.card_product import CardProduct
from synctera_client_ng.models.card_product_all_of import CardProductAllOf
from synctera_client_ng.models.card_product_list_response import CardProductListResponse
from synctera_client_ng.models.card_product_list_response_all_of import CardProductListResponseAllOf
from synctera_client_ng.models.card_product_response import CardProductResponse
from synctera_client_ng.models.card_response import CardResponse
from synctera_client_ng.models.card_status import CardStatus
from synctera_client_ng.models.card_status_object import CardStatusObject
from synctera_client_ng.models.card_status_reason_code import CardStatusReasonCode
from synctera_client_ng.models.card_status_request import CardStatusRequest
from synctera_client_ng.models.card_widget_url_response import CardWidgetUrlResponse
from synctera_client_ng.models.cash_pickup import CashPickup
from synctera_client_ng.models.cash_pickup_all_of import CashPickupAllOf
from synctera_client_ng.models.cash_pickup_list import CashPickupList
from synctera_client_ng.models.cash_pickup_list_all_of import CashPickupListAllOf
from synctera_client_ng.models.cash_pickup_patch_request import CashPickupPatchRequest
from synctera_client_ng.models.cash_pickup_patch_request_all_of import CashPickupPatchRequestAllOf
from synctera_client_ng.models.cash_pickup_post_request import CashPickupPostRequest
from synctera_client_ng.models.cash_pickup_status import CashPickupStatus
from synctera_client_ng.models.change_channel import ChangeChannel
from synctera_client_ng.models.change_type import ChangeType
from synctera_client_ng.models.clearing_model import ClearingModel
from synctera_client_ng.models.client_token import ClientToken
from synctera_client_ng.models.create_card_image_request import CreateCardImageRequest
from synctera_client_ng.models.create_gateway_request import CreateGatewayRequest
from synctera_client_ng.models.create_secret201_response import CreateSecret201Response
from synctera_client_ng.models.customer import Customer
from synctera_client_ng.models.customer_all_of import CustomerAllOf
from synctera_client_ng.models.customer_in_body import CustomerInBody
from synctera_client_ng.models.customer_kyc_status import CustomerKycStatus
from synctera_client_ng.models.customer_list import CustomerList
from synctera_client_ng.models.customer_list_all_of import CustomerListAllOf
from synctera_client_ng.models.customer_type import CustomerType
from synctera_client_ng.models.customer_verification import CustomerVerification
from synctera_client_ng.models.customer_verification_result import CustomerVerificationResult
from synctera_client_ng.models.customer_verification_result_list import CustomerVerificationResultList
from synctera_client_ng.models.customer_verification_result_list_all_of import CustomerVerificationResultListAllOf
from synctera_client_ng.models.customer_verify_response import CustomerVerifyResponse
from synctera_client_ng.models.customer_verify_response_all_of import CustomerVerifyResponseAllOf
from synctera_client_ng.models.dc_sign import DcSign
from synctera_client_ng.models.delete_response import DeleteResponse
from synctera_client_ng.models.deposit import Deposit
from synctera_client_ng.models.deposit_list import DepositList
from synctera_client_ng.models.deposit_list_all_of import DepositListAllOf
from synctera_client_ng.models.detail import Detail
from synctera_client_ng.models.device_type import DeviceType
from synctera_client_ng.models.digital_wallet_token_address_verification import DigitalWalletTokenAddressVerification
from synctera_client_ng.models.digital_wallet_token_edit_request import DigitalWalletTokenEditRequest
from synctera_client_ng.models.digital_wallet_token_response import DigitalWalletTokenResponse
from synctera_client_ng.models.digital_wallet_token_state import DigitalWalletTokenState
from synctera_client_ng.models.digital_wallet_tokenization import DigitalWalletTokenization
from synctera_client_ng.models.direction import Direction
from synctera_client_ng.models.disclosure import Disclosure
from synctera_client_ng.models.disclosure1 import Disclosure1
from synctera_client_ng.models.disclosure_list import DisclosureList
from synctera_client_ng.models.disclosure_list_all_of import DisclosureListAllOf
from synctera_client_ng.models.disclosure_response import DisclosureResponse
from synctera_client_ng.models.disclosure_type import DisclosureType
from synctera_client_ng.models.document import Document
from synctera_client_ng.models.document_list import DocumentList
from synctera_client_ng.models.document_list_all_of import DocumentListAllOf
from synctera_client_ng.models.document_type import DocumentType
from synctera_client_ng.models.emboss_name import EmbossName
from synctera_client_ng.models.employment import Employment
from synctera_client_ng.models.employment_list import EmploymentList
from synctera_client_ng.models.employment_list_all_of import EmploymentListAllOf
from synctera_client_ng.models.encryption import Encryption
from synctera_client_ng.models.error import Error
from synctera_client_ng.models.event import Event
from synctera_client_ng.models.event_list import EventList
from synctera_client_ng.models.event_list_all_of import EventListAllOf
from synctera_client_ng.models.event_trigger import EventTrigger
from synctera_client_ng.models.event_type import EventType
from synctera_client_ng.models.event_type_explicit import EventTypeExplicit
from synctera_client_ng.models.event_type_wildcard import EventTypeWildcard
from synctera_client_ng.models.ext_account_customer_type import ExtAccountCustomerType
from synctera_client_ng.models.external_account import ExternalAccount
from synctera_client_ng.models.external_account_access_token import ExternalAccountAccessToken
from synctera_client_ng.models.external_account_balance import ExternalAccountBalance
from synctera_client_ng.models.external_account_link_token import ExternalAccountLinkToken
from synctera_client_ng.models.external_account_transaction import ExternalAccountTransaction
from synctera_client_ng.models.external_account_vendor_data import ExternalAccountVendorData
from synctera_client_ng.models.external_account_vendor_values import ExternalAccountVendorValues
from synctera_client_ng.models.external_accounts_list import ExternalAccountsList
from synctera_client_ng.models.external_accounts_list_all_of import ExternalAccountsListAllOf
from synctera_client_ng.models.external_accounts_transaction_list import ExternalAccountsTransactionList
from synctera_client_ng.models.external_card_list_response import ExternalCardListResponse
from synctera_client_ng.models.external_card_list_response_all_of import ExternalCardListResponseAllOf
from synctera_client_ng.models.external_card_request import ExternalCardRequest
from synctera_client_ng.models.external_card_response import ExternalCardResponse
from synctera_client_ng.models.external_card_verifications import ExternalCardVerifications
from synctera_client_ng.models.fee import Fee
from synctera_client_ng.models.financial_institution import FinancialInstitution
from synctera_client_ng.models.financial_request_model import FinancialRequestModel
from synctera_client_ng.models.finicity_account_verification import FinicityAccountVerification
from synctera_client_ng.models.form import Form
from synctera_client_ng.models.fulfillment_details import FulfillmentDetails
from synctera_client_ng.models.gateway_list_response import GatewayListResponse
from synctera_client_ng.models.gateway_list_response_all_of import GatewayListResponseAllOf
from synctera_client_ng.models.gateway_response import GatewayResponse
from synctera_client_ng.models.get_card_barcode200_response import GetCardBarcode200Response
from synctera_client_ng.models.google_digital_wallet_provision_request import GoogleDigitalWalletProvisionRequest
from synctera_client_ng.models.google_digital_wallet_provision_response import GoogleDigitalWalletProvisionResponse
from synctera_client_ng.models.hold_data import HoldData
from synctera_client_ng.models.in_app_provisioning import InAppProvisioning
from synctera_client_ng.models.interest import Interest
from synctera_client_ng.models.internal_account import InternalAccount
from synctera_client_ng.models.internal_account_patch import InternalAccountPatch
from synctera_client_ng.models.internal_account_post import InternalAccountPost
from synctera_client_ng.models.internal_account_post_all_of import InternalAccountPostAllOf
from synctera_client_ng.models.internal_account_purpose import InternalAccountPurpose
from synctera_client_ng.models.internal_account_response import InternalAccountResponse
from synctera_client_ng.models.internal_account_response_all_of import InternalAccountResponseAllOf
from synctera_client_ng.models.internal_account_type import InternalAccountType
from synctera_client_ng.models.internal_accounts_list import InternalAccountsList
from synctera_client_ng.models.internal_accounts_list_all_of import InternalAccountsListAllOf
from synctera_client_ng.models.internal_transfer import InternalTransfer
from synctera_client_ng.models.internal_transfer_instruction import InternalTransferInstruction
from synctera_client_ng.models.internal_transfer_patch import InternalTransferPatch
from synctera_client_ng.models.internal_transfer_response import InternalTransferResponse
from synctera_client_ng.models.internal_transfer_response_all_of import InternalTransferResponseAllOf
from synctera_client_ng.models.manual_account_verification import ManualAccountVerification
from synctera_client_ng.models.manual_entry import ManualEntry
from synctera_client_ng.models.merchant import Merchant
from synctera_client_ng.models.minimum_payment import MinimumPayment
from synctera_client_ng.models.minimum_payment_full import MinimumPaymentFull
from synctera_client_ng.models.minimum_payment_partial import MinimumPaymentPartial
from synctera_client_ng.models.minimum_payment_type import MinimumPaymentType
from synctera_client_ng.models.minimum_payment_type_full import MinimumPaymentTypeFull
from synctera_client_ng.models.minimum_payment_type_rate_or_amount import MinimumPaymentTypeRateOrAmount
from synctera_client_ng.models.monitoring_alert import MonitoringAlert
from synctera_client_ng.models.monitoring_alert_list import MonitoringAlertList
from synctera_client_ng.models.monitoring_alert_list_all_of import MonitoringAlertListAllOf
from synctera_client_ng.models.monitoring_status import MonitoringStatus
from synctera_client_ng.models.monitoring_subscription import MonitoringSubscription
from synctera_client_ng.models.monitoring_subscription_list import MonitoringSubscriptionList
from synctera_client_ng.models.monitoring_subscription_list_all_of import MonitoringSubscriptionListAllOf
from synctera_client_ng.models.network_fee_model import NetworkFeeModel
from synctera_client_ng.models.note_create import NoteCreate
from synctera_client_ng.models.note_list import NoteList
from synctera_client_ng.models.note_list_all_of import NoteListAllOf
from synctera_client_ng.models.note_response import NoteResponse
from synctera_client_ng.models.original_credit_request_model import OriginalCreditRequestModel
from synctera_client_ng.models.original_credit_sender_data import OriginalCreditSenderData
from synctera_client_ng.models.outgoing_ach import OutgoingAch
from synctera_client_ng.models.outgoing_ach_list import OutgoingAchList
from synctera_client_ng.models.outgoing_ach_list_all_of import OutgoingAchListAllOf
from synctera_client_ng.models.outgoing_ach_patch import OutgoingAchPatch
from synctera_client_ng.models.outgoing_ach_request import OutgoingAchRequest
from synctera_client_ng.models.paginated_response import PaginatedResponse
from synctera_client_ng.models.paginated_response1 import PaginatedResponse1
from synctera_client_ng.models.patch_account import PatchAccount
from synctera_client_ng.models.patch_account_charge_secured import PatchAccountChargeSecured
from synctera_client_ng.models.patch_account_charge_secured_all_of import PatchAccountChargeSecuredAllOf
from synctera_client_ng.models.patch_account_line_of_credit import PatchAccountLineOfCredit
from synctera_client_ng.models.patch_account_line_of_credit_all_of import PatchAccountLineOfCreditAllOf
from synctera_client_ng.models.patch_account_product import PatchAccountProduct
from synctera_client_ng.models.patch_accounts_request_account_identifiers import PatchAccountsRequestAccountIdentifiers
from synctera_client_ng.models.patch_accounts_request_routing_identifiers import PatchAccountsRequestRoutingIdentifiers
from synctera_client_ng.models.patch_business import PatchBusiness
from synctera_client_ng.models.patch_business_business_owner_relationship import PatchBusinessBusinessOwnerRelationship
from synctera_client_ng.models.patch_business_business_owner_relationship_all_of import PatchBusinessBusinessOwnerRelationshipAllOf
from synctera_client_ng.models.patch_customer import PatchCustomer
from synctera_client_ng.models.patch_document import PatchDocument
from synctera_client_ng.models.patch_external_account import PatchExternalAccount
from synctera_client_ng.models.patch_interest import PatchInterest
from synctera_client_ng.models.patch_note import PatchNote
from synctera_client_ng.models.patch_payment_schedule import PatchPaymentSchedule
from synctera_client_ng.models.patch_person import PatchPerson
from synctera_client_ng.models.patch_person_all_of import PatchPersonAllOf
from synctera_client_ng.models.patch_person_business_owner_relationship import PatchPersonBusinessOwnerRelationship
from synctera_client_ng.models.patch_person_business_owner_relationship_all_of import PatchPersonBusinessOwnerRelationshipAllOf
from synctera_client_ng.models.patch_person_business_relationship import PatchPersonBusinessRelationship
from synctera_client_ng.models.patch_person_business_relationship_all_of import PatchPersonBusinessRelationshipAllOf
from synctera_client_ng.models.patch_personal_id import PatchPersonalId
from synctera_client_ng.models.patch_relationship_in import PatchRelationshipIn
from synctera_client_ng.models.payment import Payment
from synctera_client_ng.models.payment_date import PaymentDate
from synctera_client_ng.models.payment_error_details import PaymentErrorDetails
from synctera_client_ng.models.payment_instruction import PaymentInstruction
from synctera_client_ng.models.payment_list import PaymentList
from synctera_client_ng.models.payment_list_all_of import PaymentListAllOf
from synctera_client_ng.models.payment_schedule import PaymentSchedule
from synctera_client_ng.models.payment_schedule_list import PaymentScheduleList
from synctera_client_ng.models.payment_schedule_list_all_of import PaymentScheduleListAllOf
from synctera_client_ng.models.payment_schedule_status import PaymentScheduleStatus
from synctera_client_ng.models.payment_status import PaymentStatus
from synctera_client_ng.models.payment_type import PaymentType
from synctera_client_ng.models.pending_transaction import PendingTransaction
from synctera_client_ng.models.pending_transaction_data import PendingTransactionData
from synctera_client_ng.models.pending_transaction_history import PendingTransactionHistory
from synctera_client_ng.models.pending_transaction_history_data import PendingTransactionHistoryData
from synctera_client_ng.models.pending_transactions import PendingTransactions
from synctera_client_ng.models.person import Person
from synctera_client_ng.models.person_business_owner_relationship import PersonBusinessOwnerRelationship
from synctera_client_ng.models.person_business_relationship import PersonBusinessRelationship
from synctera_client_ng.models.person_list import PersonList
from synctera_client_ng.models.person_list_all_of import PersonListAllOf
from synctera_client_ng.models.personal_id_base import PersonalIdBase
from synctera_client_ng.models.personal_id_country_code_post import PersonalIdCountryCodePost
from synctera_client_ng.models.personal_id_country_code_response import PersonalIdCountryCodeResponse
from synctera_client_ng.models.personal_id_customer_id import PersonalIdCustomerId
from synctera_client_ng.models.personal_id_type import PersonalIdType
from synctera_client_ng.models.physical_card import PhysicalCard
from synctera_client_ng.models.physical_card_all_of import PhysicalCardAllOf
from synctera_client_ng.models.physical_card_format import PhysicalCardFormat
from synctera_client_ng.models.physical_card_issuance_request import PhysicalCardIssuanceRequest
from synctera_client_ng.models.physical_card_plus_status import PhysicalCardPlusStatus
from synctera_client_ng.models.physical_card_response import PhysicalCardResponse
from synctera_client_ng.models.physical_card_response_all_of import PhysicalCardResponseAllOf
from synctera_client_ng.models.physical_card_response_status import PhysicalCardResponseStatus
from synctera_client_ng.models.physical_card_response_status_all_of import PhysicalCardResponseStatusAllOf
from synctera_client_ng.models.plaid_account_verification import PlaidAccountVerification
from synctera_client_ng.models.post_person import PostPerson
from synctera_client_ng.models.post_person_all_of import PostPersonAllOf
from synctera_client_ng.models.post_personal_id import PostPersonalId
from synctera_client_ng.models.post_personal_id_w_cust import PostPersonalIdWCust
from synctera_client_ng.models.post_personal_ids_array import PostPersonalIdsArray
from synctera_client_ng.models.posted_transaction import PostedTransaction
from synctera_client_ng.models.posted_transaction_data import PostedTransactionData
from synctera_client_ng.models.posted_transactions import PostedTransactions
from synctera_client_ng.models.prefill_request import PrefillRequest
from synctera_client_ng.models.prospect import Prospect
from synctera_client_ng.models.provider_type import ProviderType
from synctera_client_ng.models.provisioning_controls import ProvisioningControls
from synctera_client_ng.models.push_tokenize_request_data import PushTokenizeRequestData
from synctera_client_ng.models.rate_details import RateDetails
from synctera_client_ng.models.raw_response import RawResponse
from synctera_client_ng.models.recipient_name import RecipientName
from synctera_client_ng.models.related_resource_type import RelatedResourceType
from synctera_client_ng.models.related_resource_type1 import RelatedResourceType1
from synctera_client_ng.models.relationship import Relationship
from synctera_client_ng.models.relationship1 import Relationship1
from synctera_client_ng.models.relationship_in import RelationshipIn
from synctera_client_ng.models.relationship_list import RelationshipList
from synctera_client_ng.models.relationship_list_all_of import RelationshipListAllOf
from synctera_client_ng.models.relationship_role import RelationshipRole
from synctera_client_ng.models.relationships_list import RelationshipsList
from synctera_client_ng.models.relationships_list_all_of import RelationshipsListAllOf
from synctera_client_ng.models.replace_secret200_response import ReplaceSecret200Response
from synctera_client_ng.models.replace_secret_request import ReplaceSecretRequest
from synctera_client_ng.models.response_history_item import ResponseHistoryItem
from synctera_client_ng.models.response_person import ResponsePerson
from synctera_client_ng.models.response_personal_id import ResponsePersonalId
from synctera_client_ng.models.response_personal_id_w_cust import ResponsePersonalIdWCust
from synctera_client_ng.models.response_personal_ids_array import ResponsePersonalIdsArray
from synctera_client_ng.models.reversal_model import ReversalModel
from synctera_client_ng.models.risk_data import RiskData
from synctera_client_ng.models.risk_rating import RiskRating
from synctera_client_ng.models.risk_rating_list import RiskRatingList
from synctera_client_ng.models.risk_rating_list_all_of import RiskRatingListAllOf
from synctera_client_ng.models.savings_summary import SavingsSummary
from synctera_client_ng.models.schedule_config import ScheduleConfig
from synctera_client_ng.models.security import Security
from synctera_client_ng.models.shipping import Shipping
from synctera_client_ng.models.simulate_card_fulfillment import SimulateCardFulfillment
from synctera_client_ng.models.single_use_token_request import SingleUseTokenRequest
from synctera_client_ng.models.single_use_token_response import SingleUseTokenResponse
from synctera_client_ng.models.spend_control import SpendControl
from synctera_client_ng.models.spend_control_direction import SpendControlDirection
from synctera_client_ng.models.spend_control_response import SpendControlResponse
from synctera_client_ng.models.spend_control_response_all_of import SpendControlResponseAllOf
from synctera_client_ng.models.spend_control_response_list import SpendControlResponseList
from synctera_client_ng.models.spend_control_response_list_all_of import SpendControlResponseListAllOf
from synctera_client_ng.models.spend_control_rolling_window_days import SpendControlRollingWindowDays
from synctera_client_ng.models.spend_control_rolling_window_days_all_of import SpendControlRollingWindowDaysAllOf
from synctera_client_ng.models.spend_control_time_range import SpendControlTimeRange
from synctera_client_ng.models.spend_control_time_range_type import SpendControlTimeRangeType
from synctera_client_ng.models.spend_control_update_request import SpendControlUpdateRequest
from synctera_client_ng.models.spending_limit_with_time import SpendingLimitWithTime
from synctera_client_ng.models.spending_limits import SpendingLimits
from synctera_client_ng.models.spending_limits_transaction import SpendingLimitsTransaction
from synctera_client_ng.models.ssn_source import SsnSource
from synctera_client_ng.models.statement import Statement
from synctera_client_ng.models.statement_all_of import StatementAllOf
from synctera_client_ng.models.statement_list import StatementList
from synctera_client_ng.models.statement_list_all_of import StatementListAllOf
from synctera_client_ng.models.statement_summary import StatementSummary
from synctera_client_ng.models.status import Status
from synctera_client_ng.models.status1 import Status1
from synctera_client_ng.models.status2 import Status2
from synctera_client_ng.models.template_fields import TemplateFields
from synctera_client_ng.models.template_fields_charge_secured import TemplateFieldsChargeSecured
from synctera_client_ng.models.template_fields_charge_secured_all_of import TemplateFieldsChargeSecuredAllOf
from synctera_client_ng.models.template_fields_depository import TemplateFieldsDepository
from synctera_client_ng.models.template_fields_depository_all_of import TemplateFieldsDepositoryAllOf
from synctera_client_ng.models.template_fields_generic_response import TemplateFieldsGenericResponse
from synctera_client_ng.models.template_fields_line_of_credit import TemplateFieldsLineOfCredit
from synctera_client_ng.models.template_fields_line_of_credit_all_of import TemplateFieldsLineOfCreditAllOf
from synctera_client_ng.models.template_list import TemplateList
from synctera_client_ng.models.template_list_all_of import TemplateListAllOf
from synctera_client_ng.models.three_ds_policy import ThreeDsPolicy
from synctera_client_ng.models.token_list import TokenList
from synctera_client_ng.models.token_list_response import TokenListResponse
from synctera_client_ng.models.transaction import Transaction
from synctera_client_ng.models.transaction_data import TransactionData
from synctera_client_ng.models.transaction_line import TransactionLine
from synctera_client_ng.models.transaction_line1 import TransactionLine1
from synctera_client_ng.models.transaction_list import TransactionList
from synctera_client_ng.models.transaction_list_all_of import TransactionListAllOf
from synctera_client_ng.models.transaction_options import TransactionOptions
from synctera_client_ng.models.transfer_list_response import TransferListResponse
from synctera_client_ng.models.transfer_list_response_all_of import TransferListResponseAllOf
from synctera_client_ng.models.transfer_request import TransferRequest
from synctera_client_ng.models.transfer_request_base import TransferRequestBase
from synctera_client_ng.models.transfer_request_pull import TransferRequestPull
from synctera_client_ng.models.transfer_request_pull_all_of import TransferRequestPullAllOf
from synctera_client_ng.models.transfer_request_push import TransferRequestPush
from synctera_client_ng.models.transfer_request_push_all_of import TransferRequestPushAllOf
from synctera_client_ng.models.transfer_response import TransferResponse
from synctera_client_ng.models.transfer_response_base import TransferResponseBase
from synctera_client_ng.models.transfer_response_pull import TransferResponsePull
from synctera_client_ng.models.transfer_response_push import TransferResponsePush
from synctera_client_ng.models.transfer_reversal_request import TransferReversalRequest
from synctera_client_ng.models.transfer_type import TransferType
from synctera_client_ng.models.transfer_type_request import TransferTypeRequest
from synctera_client_ng.models.trigger_event_request import TriggerEventRequest
from synctera_client_ng.models.txn_enhancer import TxnEnhancer
from synctera_client_ng.models.type import Type
from synctera_client_ng.models.update_card_image_request import UpdateCardImageRequest
from synctera_client_ng.models.update_gateway_request import UpdateGatewayRequest
from synctera_client_ng.models.update_transfer import UpdateTransfer
from synctera_client_ng.models.vendor_info import VendorInfo
from synctera_client_ng.models.vendor_info1 import VendorInfo1
from synctera_client_ng.models.vendor_json import VendorJson
from synctera_client_ng.models.vendor_xml import VendorXml
from synctera_client_ng.models.verification import Verification
from synctera_client_ng.models.verification_all_of import VerificationAllOf
from synctera_client_ng.models.verification_list import VerificationList
from synctera_client_ng.models.verification_list_all_of import VerificationListAllOf
from synctera_client_ng.models.verification_request import VerificationRequest
from synctera_client_ng.models.verification_request_all_of import VerificationRequestAllOf
from synctera_client_ng.models.verification_result import VerificationResult
from synctera_client_ng.models.verification_status import VerificationStatus
from synctera_client_ng.models.verification_type import VerificationType
from synctera_client_ng.models.verification_type1 import VerificationType1
from synctera_client_ng.models.verification_vendor_info import VerificationVendorInfo
from synctera_client_ng.models.verification_vendor_info_detail import VerificationVendorInfoDetail
from synctera_client_ng.models.verification_vendor_json import VerificationVendorJson
from synctera_client_ng.models.verification_vendor_xml import VerificationVendorXml
from synctera_client_ng.models.verify_response import VerifyResponse
from synctera_client_ng.models.verify_response_all_of import VerifyResponseAllOf
from synctera_client_ng.models.virtual_card import VirtualCard
from synctera_client_ng.models.virtual_card_all_of import VirtualCardAllOf
from synctera_client_ng.models.virtual_card_issuance_request import VirtualCardIssuanceRequest
from synctera_client_ng.models.virtual_card_plus_status import VirtualCardPlusStatus
from synctera_client_ng.models.virtual_card_response import VirtualCardResponse
from synctera_client_ng.models.virtual_card_response_all_of import VirtualCardResponseAllOf
from synctera_client_ng.models.virtual_card_response_status import VirtualCardResponseStatus
from synctera_client_ng.models.wallet_provider_card_on_file import WalletProviderCardOnFile
from synctera_client_ng.models.watchlist_alert import WatchlistAlert
from synctera_client_ng.models.watchlist_alert_list import WatchlistAlertList
from synctera_client_ng.models.watchlist_alert_list_all_of import WatchlistAlertListAllOf
from synctera_client_ng.models.watchlist_subscription import WatchlistSubscription
from synctera_client_ng.models.watchlist_subscription_list import WatchlistSubscriptionList
from synctera_client_ng.models.watchlist_subscription_list_all_of import WatchlistSubscriptionListAllOf
from synctera_client_ng.models.watchlist_suppress import WatchlistSuppress
from synctera_client_ng.models.webhook import Webhook
from synctera_client_ng.models.webhook_list import WebhookList
from synctera_client_ng.models.webhook_list_all_of import WebhookListAllOf
from synctera_client_ng.models.webhook_request_object import WebhookRequestObject
from synctera_client_ng.models.widget_type import WidgetType
from synctera_client_ng.models.wire import Wire
from synctera_client_ng.models.wire_list import WireList
from synctera_client_ng.models.wire_list_all_of import WireListAllOf
from synctera_client_ng.models.wire_request import WireRequest
from synctera_client_ng.models.withdrawal_request_model import WithdrawalRequestModel



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr

class MinimumPaymentTypeRateOrAmount(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    min_amount: StrictInt = Field(..., description="The minimum amount to charge as a minimum payment, in cents. For example, to set the minimum to $30, set this value to 3000. Note: despite setting this value, the minimum payment will never be greater than the statement balance. ")
    rate: StrictInt = Field(..., description="The percentage of the balance to use, in basis points. For example, to set 12.5% of the balance, set this value to 1250. ")
    type: StrictStr = ...
    __properties = ["min_amount", "rate", "type"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MinimumPaymentTypeRateOrAmount:
        """Create an instance of MinimumPaymentTypeRateOrAmount from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MinimumPaymentTypeRateOrAmount:
        """Create an instance of MinimumPaymentTypeRateOrAmount from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return MinimumPaymentTypeRateOrAmount.parse_obj(obj)

        _obj = MinimumPaymentTypeRateOrAmount.parse_obj({
            "min_amount": obj.get("min_amount"),
            "rate": obj.get("rate"),
            "type": obj.get("type")
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist, constr, validator
from synctera_client_ng.models.account_access_status import AccountAccessStatus
from synctera_client_ng.models.account_type import AccountType
from synctera_client_ng.models.balance import Balance
from synctera_client_ng.models.customer_type import CustomerType
from synctera_client_ng.models.security import Security
from synctera_client_ng.models.status import Status

class AccountChargeSecured(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    access_status: Optional[AccountAccessStatus] = None
    account_number: Optional[constr(strict=True, max_length=50)] = Field(None, description="Account number")
    account_number_masked: Optional[constr(strict=True, max_length=50)] = Field(None, description="The response will contain the bank fintech ID (3 or 6 digits) plus the last 4 digits, with the digits in between replaced with * characters. Shadow mode account numbers will not be masked.")
    account_purpose: Optional[StrictStr] = Field(None, description="Purpose of the account")
    account_type: Optional[AccountType] = None
    application_id: Optional[StrictStr] = Field(None, description="The application ID for this account. ")
    balances: Optional[conlist(Balance)] = Field(None, description="A list of balances for account based on different type")
    bank_routing: Optional[constr(strict=True, max_length=9)] = Field(None, description="Bank routing number")
    creation_time: Optional[datetime] = Field(None, description="Account creation timestamp in RFC3339 format")
    currency: Optional[constr(strict=True)] = Field(None, description="Account currency or account settlement currency. ISO 4217 alphabetic currency code. Default USD")
    customer_ids: Optional[conlist(StrictStr)] = Field(None, description="A list of the customer IDs of the account holders.")
    customer_type: Optional[CustomerType] = None
    exchange_rate_type: Optional[constr(strict=True, max_length=10)] = Field(None, description="Exchange rate type")
    iban: Optional[constr(strict=True, max_length=34)] = Field(None, description="International bank account number")
    id: Optional[StrictStr] = Field(None, description="Account ID")
    is_account_pool: Optional[StrictBool] = Field(None, description="Account is investment (variable balance) account or a multi-balance account pool. Default false")
    is_ach_enabled: Optional[StrictBool] = Field(None, description="A flag to indicate whether ACH transactions are enabled.")
    is_card_enabled: Optional[StrictBool] = Field(None, description="A flag to indicate whether card transactions are enabled.")
    is_external_card_enabled: Optional[StrictBool] = Field(None, description="A flag to indicate whether external card transactions are enabled.")
    is_p2p_enabled: Optional[StrictBool] = Field(None, description="A flag to indicate whether P2P transactions are enabled.")
    is_sar_enabled: Optional[StrictBool] = Field(None, description="A flag to indicate whether SAR generation is enabled.")
    is_wire_enabled: Optional[StrictBool] = Field(None, description="A flag to indicate whether wire transactions are enabled.")
    last_updated_time: Optional[datetime] = Field(None, description="Timestamp of the last account modification in RFC3339 format")
    metadata: Optional[Dict[str, Any]] = Field(None, description="User provided account metadata")
    nickname: Optional[StrictStr] = Field(None, description="User provided account nickname")
    status: Optional[Status] = None
    swift_code: Optional[constr(strict=True, max_length=11, min_length=8)] = Field(None, description="SWIFT code")
    tenant: Optional[StrictStr] = Field(None, description="The id of the tenant containing the resource. ")
    note: Optional[StrictStr] = Field(None, description="Add an optional note when creating or updating a charged secured account. A note is required when updating the status to or from SUSPENDED")
    security: Optional[Security] = None
    __properties = ["access_status", "account_number", "account_number_masked", "account_purpose", "account_type", "application_id", "balances", "bank_routing", "creation_time", "currency", "customer_ids", "customer_type", "exchange_rate_type", "iban", "id", "is_account_pool", "is_ach_enabled", "is_card_enabled", "is_external_card_enabled", "is_p2p_enabled", "is_sar_enabled", "is_wire_enabled", "last_updated_time", "metadata", "nickname", "status", "swift_code", "tenant", "note", "security"]

    @validator('currency')
    def currency_validate_regular_expression(cls, v):
        if v is None:
            return v
        if not re.match(r"^[A-Z]{3}$", v):
            raise ValueError(r"must validate the regular expression /^[A-Z]{3}$/")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AccountChargeSecured:
        """Create an instance of AccountChargeSecured from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "account_number",
                            "account_number_masked",
                            "balances",
                            "bank_routing",
                            "creation_time",
                            "customer_ids",
                            "id",
                            "is_ach_enabled",
                            "is_card_enabled",
                            "is_external_card_enabled",
                            "is_p2p_enabled",
                            "is_sar_enabled",
                            "is_wire_enabled",
                            "last_updated_time",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in balances (list)
        _items = []
        if self.balances:
            for _item in self.balances:
                if _item:
                    _items.append(_item.to_dict())
            _dict['balances'] = _items
        # override the default output from pydantic by calling `to_dict()` of security
        if self.security:
            _dict['security'] = self.security.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AccountChargeSecured:
        """Create an instance of AccountChargeSecured from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AccountChargeSecured.parse_obj(obj)

        _obj = AccountChargeSecured.parse_obj({
            "access_status": obj.get("access_status"),
            "account_number": obj.get("account_number"),
            "account_number_masked": obj.get("account_number_masked"),
            "account_purpose": obj.get("account_purpose"),
            "account_type": obj.get("account_type"),
            "application_id": obj.get("application_id"),
            "balances": [Balance.from_dict(_item) for _item in obj.get("balances")] if obj.get("balances") is not None else None,
            "bank_routing": obj.get("bank_routing"),
            "creation_time": obj.get("creation_time"),
            "currency": obj.get("currency"),
            "customer_ids": obj.get("customer_ids"),
            "customer_type": obj.get("customer_type"),
            "exchange_rate_type": obj.get("exchange_rate_type"),
            "iban": obj.get("iban"),
            "id": obj.get("id"),
            "is_account_pool": obj.get("is_account_pool"),
            "is_ach_enabled": obj.get("is_ach_enabled"),
            "is_card_enabled": obj.get("is_card_enabled"),
            "is_external_card_enabled": obj.get("is_external_card_enabled"),
            "is_p2p_enabled": obj.get("is_p2p_enabled"),
            "is_sar_enabled": obj.get("is_sar_enabled"),
            "is_wire_enabled": obj.get("is_wire_enabled"),
            "last_updated_time": obj.get("last_updated_time"),
            "metadata": obj.get("metadata"),
            "nickname": obj.get("nickname"),
            "status": obj.get("status"),
            "swift_code": obj.get("swift_code"),
            "tenant": obj.get("tenant"),
            "note": obj.get("note"),
            "security": Security.from_dict(obj.get("security")) if obj.get("security") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class CardStatus(str, Enum):
    """
    The status indicating the card lifecycle state
    """

    """
    allowed enum values
    """
    ACTIVE = 'ACTIVE'
    UNACTIVATED = 'UNACTIVATED'
    SUSPENDED = 'SUSPENDED'
    TERMINATED = 'TERMINATED'
    IMAGE_PENDING = 'IMAGE_PENDING'
    IMAGE_REJECTED = 'IMAGE_REJECTED'




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class CardStatusReasonCode(str, Enum):
    """
    The reason for the card status  Code | Description --- | --- NEW | Card activated REQ | Requested by you INA | Dormant UNK | Invalid shipping address NEG | Negative account balance REV | Account under review SUS | Suspicious activity OUT | Activity outside program parameters FRD | Confirmed fraud MAT | Matched with an OFAC list LOS | Card reported lost CLO | Card was cloned COM | Account or card was compromised TMP | Awaiting customer confirmation PRC | Initiated by Processor ISS | Initiated by Issuer EXP | Card expired KYC | Failed KYC INF | Information was validated ACT | Account activity was validated AUX | Initiated by a third party PIN | PIN try limit reached STO | Card reported stolen ADD | Address issue NAM | Name issue SSN | SSN issue DOB | DOB issue EML | Email issue PHO | Phone issue FUL | Account/fulfillment mismatch OTH | Other 
    """

    """
    allowed enum values
    """
    NEW = 'NEW'
    REQ = 'REQ'
    INA = 'INA'
    UNK = 'UNK'
    NEG = 'NEG'
    REV = 'REV'
    SUS = 'SUS'
    OUT = 'OUT'
    FRD = 'FRD'
    MAT = 'MAT'
    LOS = 'LOS'
    CLO = 'CLO'
    COM = 'COM'
    TMP = 'TMP'
    PRC = 'PRC'
    ISS = 'ISS'
    EXP = 'EXP'
    KYC = 'KYC'
    INF = 'INF'
    ACT = 'ACT'
    AUX = 'AUX'
    PIN = 'PIN'
    STO = 'STO'
    ADD = 'ADD'
    NAM = 'NAM'
    SSN = 'SSN'
    DOB = 'DOB'
    EML = 'EML'
    PHO = 'PHO'
    FUL = 'FUL'
    OTH = 'OTH'




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from synctera_client_ng.models.account_summary import AccountSummary
from synctera_client_ng.models.business1 import Business1
from synctera_client_ng.models.person import Person
from synctera_client_ng.models.transaction import Transaction

class BaseStatementAllOf(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    account_summary: Optional[AccountSummary] = None
    authorized_signer: Optional[conlist(Person)] = None
    closing_balance: Optional[StrictInt] = Field(None, description="The account balance at the end of the statement period, in ISO 4217 minor currency units.")
    disclosure: Optional[StrictStr] = None
    joint_account_holders: Optional[conlist(Person)] = None
    opening_balance: Optional[StrictInt] = Field(None, description="The account balance at the start of the statement period, in ISO 4217 minor currency units.")
    primary_account_holder_business: Optional[Business1] = None
    primary_account_holder_personal: Optional[Person] = None
    transactions: Optional[conlist(Transaction, min_items=0)] = Field(None, description="This attribute is deprecated and will be removed in a future API version. Use `GET /v0/statements/{statement_id}/transactions` instead. ")
    transactions_omitted: Optional[StrictBool] = Field(None, description="Only appears in `statement.created` webhook payloads. Indicates that the `transactions` attribute was emptied due to webhook size constraints. If this attribute returns `true`, you may use  `GET /v0/statements/{statement_id}/transactions` to retrieve the full list. ")
    __properties = ["account_summary", "authorized_signer", "closing_balance", "disclosure", "joint_account_holders", "opening_balance", "primary_account_holder_business", "primary_account_holder_personal", "transactions", "transactions_omitted"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BaseStatementAllOf:
        """Create an instance of BaseStatementAllOf from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "authorized_signer",
                            "joint_account_holders",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of account_summary
        if self.account_summary:
            _dict['account_summary'] = self.account_summary.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in authorized_signer (list)
        _items = []
        if self.authorized_signer:
            for _item in self.authorized_signer:
                if _item:
                    _items.append(_item.to_dict())
            _dict['authorized_signer'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in joint_account_holders (list)
        _items = []
        if self.joint_account_holders:
            for _item in self.joint_account_holders:
                if _item:
                    _items.append(_item.to_dict())
            _dict['joint_account_holders'] = _items
        # override the default output from pydantic by calling `to_dict()` of primary_account_holder_business
        if self.primary_account_holder_business:
            _dict['primary_account_holder_business'] = self.primary_account_holder_business.to_dict()
        # override the default output from pydantic by calling `to_dict()` of primary_account_holder_personal
        if self.primary_account_holder_personal:
            _dict['primary_account_holder_personal'] = self.primary_account_holder_personal.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in transactions (list)
        _items = []
        if self.transactions:
            for _item in self.transactions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['transactions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BaseStatementAllOf:
        """Create an instance of BaseStatementAllOf from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return BaseStatementAllOf.parse_obj(obj)

        _obj = BaseStatementAllOf.parse_obj({
            "account_summary": AccountSummary.from_dict(obj.get("account_summary")) if obj.get("account_summary") is not None else None,
            "authorized_signer": [Person.from_dict(_item) for _item in obj.get("authorized_signer")] if obj.get("authorized_signer") is not None else None,
            "closing_balance": obj.get("closing_balance"),
            "disclosure": obj.get("disclosure"),
            "joint_account_holders": [Person.from_dict(_item) for _item in obj.get("joint_account_holders")] if obj.get("joint_account_holders") is not None else None,
            "opening_balance": obj.get("opening_balance"),
            "primary_account_holder_business": Business1.from_dict(obj.get("primary_account_holder_business")) if obj.get("primary_account_holder_business") is not None else None,
            "primary_account_holder_personal": Person.from_dict(obj.get("primary_account_holder_personal")) if obj.get("primary_account_holder_personal") is not None else None,
            "transactions": [Transaction.from_dict(_item) for _item in obj.get("transactions")] if obj.get("transactions") is not None else None,
            "transactions_omitted": obj.get("transactions_omitted")
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictBool, StrictStr, validator

class ExternalCardVerifications(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    address_verification_result: StrictStr = Field(..., description="Address verification results  Status | Description --- | --- VERIFIED | AVS verified NOT_VERIFIED | AVS not verified ADDRESS_MISMATCH | ZIP code match, address no match ZIP_MISMATCH | Address match, ZIP code no match ADDRESS_AND_ZIP_MISMATCH | Address and ZIP code no match ")
    cvv2_result: StrictStr = Field(..., description="Card Verification Value results  Status | Description --- | --- VERIFIED | CVV and expiration date verified NOT_VERIFIED | CVV and expiration date not verified CVV_MISMATCH | Either CVV or expiration date does not match NOT_SUPPORTED | Issuer does not participate in CVV2 service ")
    pull_enabled: StrictBool = Field(..., description="Indicates if the card is able to perform PULL transfers.")
    push_enabled: StrictBool = Field(..., description="Indicates if the card is able to perform PUSH transfers.")
    state: StrictStr = ...
    __properties = ["address_verification_result", "cvv2_result", "pull_enabled", "push_enabled", "state"]

    @validator('address_verification_result')
    def address_verification_result_validate_enum(cls, v):
        if v not in ('VERIFIED', 'NOT_VERIFIED', 'ADDRESS_MISMATCH', 'ZIP_MISMATCH', 'ADDRESS_AND_ZIP_MISMATCH'):
            raise ValueError("must validate the enum values ('VERIFIED', 'NOT_VERIFIED', 'ADDRESS_MISMATCH', 'ZIP_MISMATCH', 'ADDRESS_AND_ZIP_MISMATCH')")
        return v

    @validator('cvv2_result')
    def cvv2_result_validate_enum(cls, v):
        if v not in ('VERIFIED', 'NOT_VERIFIED', 'CVV_MISMATCH', 'NOT_SUPPORTED'):
            raise ValueError("must validate the enum values ('VERIFIED', 'NOT_VERIFIED', 'CVV_MISMATCH', 'NOT_SUPPORTED')")
        return v

    @validator('state')
    def state_validate_enum(cls, v):
        if v not in ('SUCCEEDED', 'FAILED'):
            raise ValueError("must validate the enum values ('SUCCEEDED', 'FAILED')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ExternalCardVerifications:
        """Create an instance of ExternalCardVerifications from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ExternalCardVerifications:
        """Create an instance of ExternalCardVerifications from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ExternalCardVerifications.parse_obj(obj)

        _obj = ExternalCardVerifications.parse_obj({
            "address_verification_result": obj.get("address_verification_result"),
            "cvv2_result": obj.get("cvv2_result"),
            "pull_enabled": obj.get("pull_enabled"),
            "push_enabled": obj.get("push_enabled"),
            "state": obj.get("state")
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 0.41.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist, constr, validator
from synctera_client_ng.models.account_verification import AccountVerification
from synctera_client_ng.models.patch_accounts_request_account_identifiers import PatchAccountsRequestAccountIdentifiers
from synctera_client_ng.models.patch_accounts_request_routing_identifiers import PatchAccountsRequestRoutingIdentifiers

class PatchExternalAccount(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    account_identifiers: Optional[PatchAccountsRequestAccountIdentifiers] = None
    account_owner_names: Optional[conlist(StrictStr)] = Field(None, description="The names of the account owners.")
    nickname: Optional[constr(strict=True, min_length=1)] = Field(None, description="A user-meaningful name for the account")
    routing_identifiers: Optional[PatchAccountsRequestRoutingIdentifiers] = None
    type: Optional[StrictStr] = Field(None, description="The type of the account")
    verification: Optional[AccountVerification] = None
    __properties = ["account_identifiers", "account_owner_names", "nickname", "routing_identifiers", "type", "verification"]

    @validator('type')
    def type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('CHECKING', 'SAVINGS'):
            raise ValueError("must validate the enum values ('CHECKING', 'SAVINGS')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PatchExternalAccount:
        """Create an instance of PatchExternalAccount from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of account_identifiers
        if self.account_identifiers:
            _dict['account_identifiers'] = self.account_identifiers.to_dict()
        # override the default output from pydantic by calling `to_dict()` of routing_identifiers
        if self.routing_identifiers:
            _dict['routing_identifiers'] = self.routing_identifiers.to_dict()
        # override the default output from pydantic by calling `to_dict()` of verification
        if self.verification:
            _dict['verification'] = self.verification.to_dict()
        # set to None if verification (nullable) is None
        if self.verification is None:
            _dict['verification'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PatchExternalAccount:
        """Create an instance of PatchExternalAccount from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PatchExternalAccount.parse_obj(obj)

        _obj = PatchExternalAccount.parse_obj({
            "account_identifiers": PatchAccountsRequestAccountIdentifiers.from_dict(obj.get("account_identifiers")) if obj.get("account_identifiers") is not None else None,
            "account_owner_names": obj.get("account_owner_names"),
            "nickname": obj.get("nickname"),
            "routing_identifiers": PatchAccountsRequestRoutingIdentifiers.from_dict(obj.get("routing_identifiers")) if obj.get("routing_identifiers") is not None else None,
            "type": obj.get("type"),
            "verification": AccountVerification.from_dict(obj.get("verification")) if obj.get("verification") is not None else None
        })
        return _obj

